rust

package
v0.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package rust holds Rust-language detectors.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ActixWebDetector

type ActixWebDetector struct{}

ActixWebDetector detects Actix-web and Axum endpoints, plus middleware layers and #[actix_web::main]/#[tokio::main] entry-point modules. Mirrors Java ActixWebDetector.

func NewActixWebDetector

func NewActixWebDetector() *ActixWebDetector

func (ActixWebDetector) DefaultConfidence

func (ActixWebDetector) DefaultConfidence() model.Confidence

func (ActixWebDetector) Detect

func (ActixWebDetector) Name

func (ActixWebDetector) Name() string

func (ActixWebDetector) SupportedLanguages

func (ActixWebDetector) SupportedLanguages() []string

type StructuresDetector

type StructuresDetector struct{}

StructuresDetector detects Rust modules, structs, traits, impls, functions, enums, macros, and use statements. Mirrors Java RustStructuresDetector.

func NewStructuresDetector

func NewStructuresDetector() *StructuresDetector

func (StructuresDetector) DefaultConfidence

func (StructuresDetector) DefaultConfidence() model.Confidence

func (StructuresDetector) Detect

func (StructuresDetector) Name

func (StructuresDetector) Name() string

func (StructuresDetector) SupportedLanguages

func (StructuresDetector) SupportedLanguages() []string

Jump to