Documentation
¶
Overview ¶
Package rust holds Rust-language detectors.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActixWebDetector ¶
type ActixWebDetector struct{}
ActixWebDetector detects Actix-web and Axum endpoints, plus middleware layers and #[actix_web::main]/#[tokio::main] entry-point modules. Mirrors Java ActixWebDetector.
func NewActixWebDetector ¶
func NewActixWebDetector() *ActixWebDetector
func (ActixWebDetector) DefaultConfidence ¶
func (ActixWebDetector) DefaultConfidence() model.Confidence
func (ActixWebDetector) Detect ¶
func (d ActixWebDetector) Detect(ctx *detector.Context) *detector.Result
func (ActixWebDetector) Name ¶
func (ActixWebDetector) Name() string
func (ActixWebDetector) SupportedLanguages ¶
func (ActixWebDetector) SupportedLanguages() []string
type StructuresDetector ¶
type StructuresDetector struct{}
StructuresDetector detects Rust modules, structs, traits, impls, functions, enums, macros, and use statements. Mirrors Java RustStructuresDetector.
func NewStructuresDetector ¶
func NewStructuresDetector() *StructuresDetector
func (StructuresDetector) DefaultConfidence ¶
func (StructuresDetector) DefaultConfidence() model.Confidence
func (StructuresDetector) Detect ¶
func (d StructuresDetector) Detect(ctx *detector.Context) *detector.Result
func (StructuresDetector) Name ¶
func (StructuresDetector) Name() string
func (StructuresDetector) SupportedLanguages ¶
func (StructuresDetector) SupportedLanguages() []string
Click to show internal directories.
Click to hide internal directories.